@@ -188,7 +188,8 @@ class JunosDevice(linux.LinuxDevice):
                 expect = self.original_prompt, timeout = 3, with_log = False)
         prompt = self.prompt
         self.prompt = "\[NETDEVICE\][\$\#] "
-        linux.LinuxDevice.cmd(self, self.PROMPT_SET_CSH, timeout=1, log_level = self.LOG_DEBUG)
+        linux.LinuxDevice.cmd(self, self.PROMPT_SET_CSH, timeout=1,
+                with_log = False, log_level = self.LOG_DEBUG)
 
         cprod = "cprod"
         if kwargs.get("output", None):
@@ -227,6 +228,41 @@ class JunosDevice(linux.LinuxDevice):
         linux.LinuxDevice.cmd(self, "exit", with_log = False)
         return output
 
+    #def vty (self, *args, **kwargs):
+    #    '''
+    #    equal cmd(..., mode = "vty")
+
+    #    Execute every line in every argument on every SPU(if not given) and
+    #    return the result.
+
+    #    Supported options include:
+
+    #        timeout: time to wait for the execute command return. default is 5
+    #                 seconds
+    #        tnp_addr: tnp address to execute, if not execut the command on
+    #                  every SPU.
+    #    '''
+    #    spus = kwargs.get("tnp_addr", False) and [kwargs["tnp_addr"]] or self["spus"]
+
+    #    linux.LinuxDevice.cmd(self, "run start shell csh",
+    #            expect = self.original_prompt, timeout = 3, with_log = False)
+    #    output = ""
+    #    for spu in spus:
+    #        linux.LinuxDevice.cmd(self, "vty %s" %(spu),
+    #                expect = "vty\)# ", timeout = 5, with_log = False)
+    #        for cmd in args:
+    #            with StringIO(cmd) as f:
+    #                for line in f.readlines():
+    #                    output += linux.LinuxDevice.cmd(self, line.strip(),
+    #                            expect = ["vty\)# ", "---(more)---"],
+    #                            command_leading = "%s(vty)# "%(spu), **kwargs)
+    #        linux.LinuxDevice.cmd(self, "quit",
+    #                expect = self.original_prompt, timeout = 3, with_log = False)
+
+    #    # return to the configure mode.
+    #    linux.LinuxDevice.cmd(self, "exit", with_log = False)
+    #    return output
+
     def reboot (self):
         '''
         reboot the device and reconnect to it until it bootup.
@@ -505,7 +541,7 @@ class JunosDevice(linux.LinuxDevice):
                 interface[family_name].append(ipaddress.ip_interface(unicode(ipaddr)))
         return interface
 
-    def x_configure_interface (self, *args, **kwargs):
+    def x_set_interface (self, *args, **kwargs):
         """
         Re-configure the interface with the given parameters.
 
@@ -517,7 +553,7 @@ class JunosDevice(linux.LinuxDevice):
                     "inet": "41.0.0.111/24",
                     "inet6": "2001::111/64",
                     "zone": "trust" }
-            dut.x_configure_interface(int0)
+            dut.x_set_interface(int0)
         """
         #print("%s.%s invoked" %(self.__class__.__name__, sys._getframe().f_code.co_name))
         for arg in args:
@@ -530,7 +566,100 @@ class JunosDevice(linux.LinuxDevice):
             if "inet6" in arg.keys():
                 self.configure("set security forwarding-options family inet6 mode flow-based", **kwargs)
                 self.configure("set interfaces %s unit %s family inet6 address %s" %(name[0], name[1], arg["inet6"]), **kwargs)
-        self.configure("commit", **kwargs)
+        #self.configure("commit", **kwargs)
+
+    def x_set_zone (self, zone = None, interfaces = None,
+            services = "all", protocols = "all"):
+        """
+        Delete the @zone and re-configure it with the new parameters.
+
+        call examples:
+            dut.x_set_zone("trust", "xe-9/0/2.0", "all", "all")
+            dut.x_set_zone("untrust", ["reth1.0", "reth3.0"], "all", "all")
+        """
+        #print("%s.%s invoked" %(self.__class__.__name__, sys._getframe().f_code.co_name))
+        if (not zone) or (not services):
+            self.log("Please provide the zone and interfaces.")
+            return
+
+        self.configure("delete security zones security-zone %s" %(zone))
+        common_part = "set security zones security-zone %s " %(zone)
+        if isinstance(services, list):
+            for s in services:
+                self.configure(common_part + "host-inbound-traffic system-services " + s)
+        else:
+            self.configure(common_part + "host-inbound-traffic system-services " + services)
+
+        if isinstance(protocols, list):
+            for p in protocols:
+                self.configure(common_part + "host-inbound-traffic protocols " + p)
+        else:
+            self.configure(common_part + "host-inbound-traffic protocols " + protocols)
+
+        if isinstance(interfaces, list):
+            for i in interfaces:
+                self.configure(common_part +  "interfaces %s" %(i))
+        else:
+            self.configure(common_part +  "interfaces %s" %(interfaces))
+        #self.configure("commit", **kwargs)
+
+    def x_set_policy (self,
+            from_zone = "trust", to_zone = "untrust", name = "t2u",
+            source_address = "any", destination_address = "any",
+            application = "any", dynamic_application = None, 
+            action = "permit", **kwargs):
+        """
+        Re-configure the policy with the given parameters.
+
+        call examples:
+        self.dut.x_set_policy("trust", "untrust", "t2u111", "any", "any", "any",
+                              action = ["permit", "services-offload"])
+
+        """
+        #print("%s.%s invoked" %(self.__class__.__name__, sys._getframe().f_code.co_name))
+
+        # Remove all the policies in the same zone to make sure the new one is active.
+        self.configure("delete security policies from-zone %s to-zone %s"
+                %(from_zone, to_zone))
+        common_part = "set security policies from-zone %s to-zone %s policy %s "\
+                %(from_zone, to_zone, name)
+
+        # source-address
+        if isinstance(source_address, list):
+            for s in source_address:
+                self.configure(common_part +  "match source-address %s" %(s))
+        else:
+            self.configure(common_part +  "match source-address %s" %(source_address))
+
+        # destination-address
+        if isinstance(destination_address, list):
+            for d in destination_address:
+                self.configure(common_part +  "match destination-address %s" %(d))
+        else:
+            self.configure(common_part +  "match destination-address %s" %(destination_address))
+
+        # application
+        if isinstance(application, list):
+            for app in application:
+                self.configure(common_part +  "match application %s" %(app))
+        else:
+            self.configure(common_part +  "match application %s" %(application))
+
+        # dynamic-application
+        if isinstance(dynamic_application, list):
+            for dynapp in dynamic_application:
+                self.configure(common_part +  "match application %s" %(dynapp))
+        elif dynamic_application:
+            self.configure(common_part +  "match application %s" %(dynamic_application))
+
+        # action
+        action_line = common_part + "then "
+        for a in action:
+            action_line += "%s " %(a)
+        self.configure(action_line)
+
+        #self.configure("commit", **kwargs)
+
 
     def x_print_session (self, sessions):
         '''
