@@ -119,7 +119,7 @@ class LinuxDevice(object):
     '''
     A base class for common linux devices.
     '''
-    version = '1.0.3'
+    version = '1.0.8'
 
     LOG_EMERG = 0   # not used
     LOG_ALERT = 1   # not used
@@ -279,7 +279,7 @@ class LinuxDevice(object):
             self.log('Login failed: %s' %(error), color = "red")
             raise Exception ('Login failed: %s' %(error))
         #self.log("succeed to %s %s.\n" %(self["scheme"], self["hostname"]), color = "green")
-        self.log("succeed!", color = "green")
+        #self.log("succeed!", color = "green")
 
         if (self["type"] == 'Junos'):
             # Second phase
@@ -948,14 +948,14 @@ class LinuxDevice(object):
         local.cmd("%s -F" %(iptable_cmd))
         remote.cmd("%s -F" %(iptable_cmd))
 
-    def x_configure_interface (self, *args):
+    def x_set_interface (self, *args):
         """
         configure the interface with the given parameters.
         The interface looks like this, you can configure multi interfaces in
         one time, for examples:
 
-        client.x_configure_interface("eth1", "41.0.0.2", "2002::2")
-        client.x_configure_interface(name = "eth1", inet = "41.0.0.2", inet6 = "2002::2")
+        client.x_set_interface("eth1", "41.0.0.2", "2002::2")
+        client.x_set_interface(name = "eth1", inet = "41.0.0.2", inet6 = "2002::2")
 
         """
         #print "%s.%s invoked" %(self.__class__.__name__, sys._getframe().f_code.co_name)
@@ -978,12 +978,12 @@ class LinuxDevice(object):
                 self.interface[arg["name"]]["inet6"] = arg[2]
         #self.log("interface changes: %s\n" %(json.dumps(args, indent=4)))
 
-    def x_configure_route (self, local, gateway, remote):
+    def x_set_route (self, local, gateway, remote):
         """
         Re-configure the interface with the given parameters, for examples:
 
         #int0 = { 'name': 'eth1', 'inet': '41.0.0.2/24', 'inet6': '2001::2/64'}
-        client.x_configure_route(client["int0"], dut["int0"], server["int0"])
+        client.x_set_route(client["int0"], dut["int0"], server["int0"])
 
         """
         #print "%s.%s invoked" %(self.__class__.__name__, sys._getframe().f_code.co_name)
